#!/usr/bin/env node
"use strict";
/**
 * Copyright 2020 Baidu Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-var-requires */
/* eslint-disable no-console */
var ora_1 = __importDefault(require("ora"));
var ecosystem_config_1 = __importDefault(require("@visualdl/server/ecosystem.config"));
var pm2_1 = __importDefault(require("pm2"));
var app = ecosystem_config_1.default.apps[0];
var argv = require('yargs')
    .usage('Usage: $0 <command> [options]')
    .command('start', 'Start VisualDL server')
    .command('stop', 'Stop VisualDL server')
    .example('$0 start --backend="http://172.17.0.82:8040"', 'Start VisualDL server with backend address http://172.17.0.82:8040')
    .alias('p', 'port')
    .nargs('p', 1)
    .nargs('port', 1)
    .describe('p', 'Port of server')
    .nargs('host', 1)
    .describe('host', 'Host of server')
    .alias('b', 'backend')
    .nargs('b', 1)
    .nargs('backend', 1)
    .describe('b', 'Backend API address')
    .boolean('demo')
    .describe('demo', 'Run in demo mode')
    .boolean('open')
    .describe('open', 'Open browser when server is ready')
    .help('h')
    .alias('h', 'help')
    .epilog('Visit https://github.com/PaddlePaddle/VisualDL for more information.').argv;
var command = argv._[0];
var exit = function () {
    console.log('Command not found, use -h or --help for help');
    process.exit(1);
};
var exitIfError = function (err, exitCode, spinner) {
    if (exitCode === void 0) { exitCode = 1; }
    if (!err) {
        return;
    }
    if (spinner) {
        spinner.fail('Error!');
    }
    console.error(err);
    process.exit(exitCode);
};
if (!command) {
    exit();
}
var banner = "\n\n\u2588\u2588\u2588\u2588\u2588   \u2588\u2588\u2588\u2588\u2588  \u2588\u2588\u2588                               \u2588\u2588\u2588\u2588  \u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588   \u2588\u2588\u2588\u2588\u2588\n\u2591\u2591\u2588\u2588\u2588   \u2591\u2591\u2588\u2588\u2588  \u2591\u2591\u2591                               \u2591\u2591\u2588\u2588\u2588 \u2591\u2591\u2588\u2588\u2588\u2591\u2591\u2591\u2591\u2588\u2588\u2588 \u2591\u2591\u2588\u2588\u2588\n \u2591\u2588\u2588\u2588    \u2591\u2588\u2588\u2588  \u2588\u2588\u2588\u2588   \u2588\u2588\u2588\u2588\u2588  \u2588\u2588\u2588\u2588\u2588 \u2588\u2588\u2588\u2588  \u2588\u2588\u2588\u2588\u2588\u2588   \u2591\u2588\u2588\u2588  \u2591\u2588\u2588\u2588   \u2591\u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588\n \u2591\u2588\u2588\u2588    \u2591\u2588\u2588\u2588 \u2591\u2591\u2588\u2588\u2588  \u2588\u2588\u2588\u2591\u2591  \u2591\u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588  \u2591\u2591\u2591\u2591\u2591\u2588\u2588\u2588  \u2591\u2588\u2588\u2588  \u2591\u2588\u2588\u2588    \u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588\n \u2591\u2591\u2588\u2588\u2588   \u2588\u2588\u2588   \u2591\u2588\u2588\u2588 \u2591\u2591\u2588\u2588\u2588\u2588\u2588  \u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588   \u2588\u2588\u2588\u2588\u2588\u2588\u2588  \u2591\u2588\u2588\u2588  \u2591\u2588\u2588\u2588    \u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588\n  \u2591\u2591\u2591\u2588\u2588\u2588\u2588\u2588\u2591    \u2591\u2588\u2588\u2588  \u2591\u2591\u2591\u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588 \u2591\u2588\u2588\u2588  \u2588\u2588\u2588\u2591\u2591\u2588\u2588\u2588  \u2591\u2588\u2588\u2588  \u2591\u2588\u2588\u2588    \u2588\u2588\u2588  \u2591\u2588\u2588\u2588      \u2588\n    \u2591\u2591\u2588\u2588\u2588      \u2588\u2588\u2588\u2588\u2588 \u2588\u2588\u2588\u2588\u2588\u2588  \u2591\u2591\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2591\u2591\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588 \u2588\u2588\u2588\u2588\u2588 \u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588   \u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\u2588\n     \u2591\u2591\u2591      \u2591\u2591\u2591\u2591\u2591 \u2591\u2591\u2591\u2591\u2591\u2591    \u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591  \u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591 \u2591\u2591\u2591\u2591\u2591 \u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591   \u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591\u2591\n\n\n\n";
pm2_1.default.connect(function (err) {
    exitIfError(err, 2);
    pm2_1.default.list(function (err, list) {
        exitIfError(err, 2);
        var host = argv.host || 'localhost';
        var port = Number.parseInt(argv.port, 10) || 8999;
        var url = "http://" + host + ":" + port;
        if (command === 'start') {
            if (list.find(function (item) { return item.name === app.name; })) {
                exitIfError(new Error('VisualDL server is already running'), 1);
            }
            var spinner_1 = ora_1.default('Starting VisualDL server...').start();
            pm2_1.default.start(__assign(__assign({}, app), { env: __assign(__assign({}, app.env), { HOST: host, PORT: port + '', BACKEND: argv.backend, DEMO: argv.demo ? '1' : '' }) }), function (err) {
                pm2_1.default.disconnect();
                exitIfError(err, 2, spinner_1);
                spinner_1.succeed('Starting VisualDL server... Done');
                console.log(banner);
                console.log("> VisualDL server is running at " + url);
                if (argv.open) {
                    console.log('  Opening your browser for you...');
                    var open_1 = require('open');
                    open_1(url);
                }
            });
        }
        else if (command === 'stop') {
            if (!list.find(function (item) { return item.name === app.name; })) {
                exitIfError(new Error('VisualDL server is not running'), 1);
            }
            var spinner_2 = ora_1.default('Stopping VisualDL server...').start();
            pm2_1.default.delete(app.name, function (err) {
                exitIfError(err, 2);
                var end = function (err) {
                    pm2_1.default.disconnect();
                    exitIfError(err, 2);
                    spinner_2.succeed('Stopping VisualDL server... Done');
                    console.log('> VisualDL server stopped');
                    console.log('  See you next time');
                    process.exit(0);
                };
                pm2_1.default.list(function (err, newList) {
                    exitIfError(err, 2);
                    if (!newList.length) {
                        pm2_1.default.killDaemon(end);
                    }
                    else {
                        end();
                    }
                });
            });
        }
        else {
            exit();
        }
    });
});
